@@ -17,3 +17,8 @@ example(prabclust)
 example(prabtest)
 example(randpop.nb)
 example(summary.prabtest)
+example(geco)
+example(geo2neighbor)
+example(hprabclust)
+example(piecewiselin)
+example(qkulczynski)
